"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.render = exports.handler = exports.help = exports.commandNames = exports.shorthands = exports.cliOptionsTypes = exports.rcOptionsTypes = void 0;
const cli_utils_1 = require("@pnpm/cli-utils");
const common_cli_options_help_1 = require("@pnpm/common-cli-options-help");
const config_1 = require("@pnpm/config");
const list_1 = require("@pnpm/list");
const pick_1 = __importDefault(require("ramda/src/pick"));
const render_help_1 = __importDefault(require("render-help"));
const recursive_1 = require("./recursive");
function rcOptionsTypes() {
    return (0, pick_1.default)([
        'depth',
        'dev',
        'global-dir',
        'global',
        'json',
        'long',
        'only',
        'optional',
        'parseable',
        'production',
    ], config_1.types);
}
exports.rcOptionsTypes = rcOptionsTypes;
const cliOptionsTypes = () => ({
    ...rcOptionsTypes(),
    'only-projects': Boolean,
    recursive: Boolean,
});
exports.cliOptionsTypes = cliOptionsTypes;
exports.shorthands = {
    D: '--dev',
    P: '--production',
};
exports.commandNames = ['list', 'ls'];
function help() {
    return (0, render_help_1.default)({
        aliases: ['list', 'ls', 'la', 'll'],
        description: 'When run as ll or la, it shows extended information by default. \
All dependencies are printed by default. Search by patterns is supported. \
For example: pnpm ls babel-* eslint-*',
        descriptionLists: [
            {
                title: 'Options',
                list: [
                    {
                        description: 'Perform command on every package in subdirectories \
or on every workspace package, when executed inside a workspace. \
For options that may be used with `-r`, see "pnpm help recursive"',
                        name: '--recursive',
                        shortAlias: '-r',
                    },
                    {
                        description: 'Show extended information',
                        name: '--long',
                    },
                    {
                        description: 'Show parseable output instead of tree view',
                        name: '--parseable',
                    },
                    {
                        description: 'Show information in JSON format',
                        name: '--json',
                    },
                    {
                        description: 'List packages in the global install prefix instead of in the current project',
                        name: '--global',
                        shortAlias: '-g',
                    },
                    {
                        description: 'Max display depth of the dependency tree',
                        name: '--depth <number>',
                    },
                    {
                        description: 'Display only direct dependencies',
                        name: '--depth 0',
                    },
                    {
                        description: 'Display only projects. Useful in a monorepo. `pnpm ls -r --depth -1` lists all projects in a monorepo',
                        name: '--depth -1',
                    },
                    {
                        description: 'Display only the dependency graph for packages in `dependencies` and `optionalDependencies`',
                        name: '--prod',
                        shortAlias: '-P',
                    },
                    {
                        description: 'Display only the dependency graph for packages in `devDependencies`',
                        name: '--dev',
                        shortAlias: '-D',
                    },
                    {
                        description: 'Display only dependencies that are also projects within the workspace',
                        name: '--only-projects',
                    },
                    {
                        description: "Don't display packages from `optionalDependencies`",
                        name: '--no-optional',
                    },
                    common_cli_options_help_1.OPTIONS.globalDir,
                    ...common_cli_options_help_1.UNIVERSAL_OPTIONS,
                ],
            },
            common_cli_options_help_1.FILTERING,
        ],
        url: (0, cli_utils_1.docsUrl)('list'),
        usages: [
            'pnpm ls [<pkg> ...]',
        ],
    });
}
exports.help = help;
async function handler(opts, params) {
    const include = {
        dependencies: opts.production !== false,
        devDependencies: opts.dev !== false,
        optionalDependencies: opts.optional !== false,
    };
    const depth = opts.cliOptions?.['depth'] ?? 0;
    if (opts.recursive && (opts.selectedProjectsGraph != null)) {
        const pkgs = Object.values(opts.selectedProjectsGraph).map((wsPkg) => wsPkg.package);
        return (0, recursive_1.listRecursive)(pkgs, params, { ...opts, depth, include });
    }
    return render([opts.dir], params, {
        ...opts,
        depth,
        include,
        lockfileDir: opts.lockfileDir ?? opts.dir,
    });
}
exports.handler = handler;
async function render(prefixes, params, opts) {
    const listOpts = {
        alwaysPrintRootPackage: opts.alwaysPrintRootPackage,
        depth: opts.depth ?? 0,
        include: opts.include,
        lockfileDir: opts.lockfileDir,
        long: opts.long,
        onlyProjects: opts.onlyProjects,
        reportAs: (opts.parseable ? 'parseable' : (opts.json ? 'json' : 'tree')),
        showExtraneous: false,
        modulesDir: opts.modulesDir,
        virtualStoreDirMaxLength: opts.virtualStoreDirMaxLength,
    };
    return (params.length > 0)
        ? (0, list_1.listForPackages)(params, prefixes, listOpts)
        : (0, list_1.list)(prefixes, listOpts);
}
exports.render = render;
//# sourceMappingURL=list.js.map