"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.listRecursive = void 0;
const assert_1 = __importDefault(require("assert"));
const util_1 = __importDefault(require("util"));
const logger_1 = require("@pnpm/logger");
const list_1 = require("./list");
async function listRecursive(pkgs, params, opts) {
    const depth = opts.depth ?? 0;
    if (opts.lockfileDir) {
        return (0, list_1.render)(pkgs.map((pkg) => pkg.dir), params, {
            ...opts,
            alwaysPrintRootPackage: depth === -1,
            lockfileDir: opts.lockfileDir,
        });
    }
    const outputs = (await Promise.all(pkgs.map(async ({ dir }) => {
        try {
            return await (0, list_1.render)([dir], params, {
                ...opts,
                alwaysPrintRootPackage: depth === -1,
                lockfileDir: opts.lockfileDir ?? dir,
            });
        }
        catch (err) {
            (0, assert_1.default)(util_1.default.types.isNativeError(err));
            const errWithPrefix = Object.assign(err, {
                prefix: dir,
            });
            logger_1.logger.info(errWithPrefix);
            throw errWithPrefix;
        }
    }))).filter(Boolean);
    if (outputs.length === 0)
        return '';
    const joiner = typeof depth === 'number' && depth > -1 ? '\n\n' : '\n';
    return outputs.join(joiner);
}
exports.listRecursive = listRecursive;
//# sourceMappingURL=recursive.js.map